@@ -5,9 +5,8 @@
 #'@importFrom Rcpp evalCpp
 #'@importFrom methods as
 #'@import Matrix
-#'@import bigmemory
 #'@useDynLib PUlasso
-#'@param X Input matrix; each row is an observation. Can be in matrix, sparse matrix or big matrix format.
+#'@param X Input matrix; each row is an observation. Can be a matrix or a sparse matrix.
 #'@param z Response vector representing whether an observation is labelled or unlabelled.
 #'@param pi True prevalence Pr(Y=1)
 #'@param initial_coef A vector representing an initial point where we start PUlasso algorithm from.
@@ -38,112 +37,6 @@ grpPUlasso <-function(X,z,pi,initial_coef=NULL,group=1:ncol(X),
                 verbose = FALSE)
 {
   if(is.null(dim(X))){stop("not a valid X")}
-  if(is.big.matrix(X)){
-    invPermute<-function(ind){
-      rind<-c()
-      for(i in 1:length(ind)){
-        rind[ind[i]]=i
-      }
-      return(rind)
-    }
-    
-    if(!is.numeric(group)){
-      group <-  as.factor(group)
-      levels(group) <-1:length(unique(group))
-      group <- as.numeric(levels(group)[group])
-    }
-    if(is.null(colnames(X))){colnames(X) <- paste("V",1:ncol(X),sep = "")}
-    X_lu<-X #X_lu and X point the same address
-    rPermute=as.numeric(order(z,decreasing = T))
-    cPermute=as.numeric(order(group))
-    # Directly change X 
-    mpermute(X_lu,order=rPermute)
-    mpermuteCols(X_lu,order=cPermute)
-    irPermute=invPermute(rPermute)
-    icPermute=invPermute(cPermute)
-    group <- group[order(group)]
-    z_lu <- z[order(z,decreasing = T)]
-
-    # Dimensions
-    N <- nrow(X_lu)
-    p <- ncol(X_lu)
-    nl <- sum(z_lu)
-    nu <- N-nl
-    J <-  length(unique(group))+1
-    
-    # Apply strong set screening if p >N
-    usestrongSet=ifelse(N<p,FALSE,TRUE)
-    
-    #input check
-    if(length(z_lu)!=N){stop("nrow(X) should be the same as length(z)")}
-    if(length(group)!=p){stop("lenght(group) should be the same as ncol(X)")}
-    if(!all(group==sort(group))){stop("columns must be in order")}
-    if(!is.null(penalty)){
-      if(length(penalty)!=(J-1)){stop("length(penalty) should be the same as the group size")}
-    }
-    if(!all(z_lu%in%c(0,1))){stop("z should be 0 or 1")}
-    # if(mean(z_lu)==0||mean(z_lu)==1){stop("y can't be all 0 or 1")}
-    if (is.null(lambda)) {
-      if (lambdaMinRatio >= 1){stop("lambdaMinRatio should be less than 1")}
-      user_lambdaseq = FALSE
-      lambdaseq = c(0.1,0.01) # will not be used
-    } else {
-      if (any(lambda < 0)){stop("lambdas should be non-negative")}
-      user_lambdaseq = TRUE
-      lambdaseq = sort(lambda, decreasing = TRUE)
-    }
-    
-    if(!(class(X_lu)=="matrix"||class(X_lu)=="dgCMatrix"||class(X_lu)=="big.matrix")){
-      stop("X must be a matrix, a sparse matrix, or a big matrix")}
-    
-    if(is.null(initial_coef)){
-      icoef <- rep(0,p+1)
-      pr <-  pi
-      icoef[1] = log(pr/(1-pr))
-      if(is.nan(icoef[1])){stop("not a valid pi=P(Y=1)")}
-    }else{
-      if(length(initial_coef)!=(p+1)){stop("length of initial_coef should be the same as ncol(X_lu)+1")}
-      icoef <- initial_coef
-    }
-    
-    gsize <-  c(1,table(group))
-    if(is.null(penalty)){
-      pen <- c(0,rep(1,J-1))*sqrt(gsize)
-    } else{
-      pen <- c(0, penalty)
-    }
-    
-      g<-LU_big_cpp(X_ = X_lu@address,z_ = z_lu,icoef_ = icoef,gsize_ = gsize,pen_ = pen,
-                    lambdaseq_ = lambdaseq,user_lambdaseq_ = user_lambdaseq,pathLength_ = nlambda,
-                    lambdaMinRatio_ = lambdaMinRatio,pi_ = pi,maxit_ = maxit,tol_ = eps,
-                    inner_tol_ = inner_eps,useStrongSet_=usestrongSet,
-                    verbose_ = verbose)
-    
-    coef <-  g$coef
-    colnames(coef) <-  paste("l",1:length(g$lambda),sep = "")
-    rownames(coef) <- c("(Intercept)",colnames(X_lu))
-    
-    std_coef <- g$std_coef
-    colnames(std_coef) <-  paste("l",1:length(g$lambda),sep = "")
-    rownames(std_coef) <- c("(Intercept)",colnames(X_lu))
-    
-    widx<-which(g$convFlag==1)
-    if(length(widx)>0){
-      for(i in 1:length(widx)){
-        warning(paste("convergence failed at ",widx[i],"th lambda, ", g$iters[widx[i]],"th iterations",sep=""))
-      }
-    }
-    
-    result <- structure(list(coef = coef, std_coef = std_coef, lambda=g$lambda,
-                             nullDev=g$nullDev,deviance=g$deviance,
-                             iters= g$iters),class="PUfit")
-    
-    #Permute back X matrix
-    mpermute(X_lu,order=as.numeric(irPermute))
-    mpermuteCols(X_lu,order=as.numeric(icPermute))
-    return(result)
-    
-  }else{
     if(!is.numeric(group)){
       group <-  as.factor(group)
       levels(group) <-1:length(unique(group))
@@ -193,7 +86,7 @@ grpPUlasso <-function(X,z,pi,initial_coef=NULL,group=1:ncol(X),
     } else if (inherits(X_lu,"dgeMatrix")){
       X_lu = as.matrix(X_lu)
     }
-    if(!(class(X_lu)=="matrix"||class(X_lu)=="dgCMatrix"||class(X_lu)=="big.matrix")){stop("X must be a matrix, a sparse matrix, or a big matrix")}
+    if(!(class(X_lu)=="matrix"||class(X_lu)=="dgCMatrix")){stop("X must be a matrix or a sparse matrix")}
    
     
     
@@ -252,6 +145,6 @@ grpPUlasso <-function(X,z,pi,initial_coef=NULL,group=1:ncol(X),
     
     
     return(result)
-  }
+  
   
 }
